# Lucipy: The simple LUCIDAC python client

This is a code to get started with the [LUCIDAC](https://anabrid.com/lucidac)
analog-digital hybrid computer. With this library, users can program the
network-enabled analog computer straight from the Python programming language.

It is a minimal python code with near-to-no dependencies. It works
best in little script files or interactively in IPython and Jupyter Notebooks
and within your favourite scientific python environment on any platform (Mac/Windows/Linux).

This is [open source code released under MIT/GPL](LICENSE.md) at
https://github.com/anabrid/lucipy and published to the Python Package Index
at https://pypi.org/project/lucipy/.

## Installation

Assuming you have a working Python installation:

```
pip install lucipy
```

Or just clone the repository (which is just online
at https://github.com/anabrid/lucipy) and import the `lucipy` directory.

## Documentation

For further information see the code documentation including usage examples
and API reference https://anabrid.dev/docs/lucipy.

